@@ -26,7 +26,6 @@ import re
 import hashlib
 import os
 from sys import argv, stderr
-from os.path import basename
 from colorama import init, Fore, Back, Style
 
 init(autoreset=True)
@@ -54,14 +53,14 @@ class Filter:
 
         self.match_count += 1
 
-        if replace_all:
+        if self.replace_all:
             self.sub_count += 1
             return replaced_match
 
         highlighted = line.replace(curr_match,
                 Back.RED + curr_match + Back.RESET)
         replaced = line.replace(curr_match,
-                Back.YELLOW + Fore.BLACK + curr_match + Back.RESET + Fore.RESET)
+                Back.YELLOW + Fore.BLACK + replaced_match + Back.RESET + Fore.RESET)
 
         print(Fore.GREEN + Style.BRIGHT + fname)
 
@@ -106,7 +105,7 @@ class Filter:
 
         lines = [
                     self.regex.sub(
-                        lambda matchobj: _prompt(matchobj, line, line_n, fname),
+                        lambda matchobj: self._prompt(matchobj, line, line_n, fname),
                         line
                     )
                     for (line_n, line) in enumerate(lines)
@@ -124,11 +123,11 @@ class Filter:
 
 def run(args):
     if len(args) < 3:
-        print('usage: {0} [REGEX] [SUB] [FILES...]'.format(basename(__file__)), file=stderr)
+        print('usage: subprompt [REGEX] [SUB] [FILES...]', file=stderr)
         exit(1)
 
     regex = args[0]
-    sub = arg[1]
+    sub = args[1]
     files = args[2:]
 
     filter_obj = Filter(regex, sub)
@@ -149,8 +148,8 @@ def run(args):
                         Fore.WHITE + str(filter_obj.match_count) + Fore.YELLOW))
 
 def main():
-    sys.argv.pop(0)
-    run(sys.argv)
+    argv.pop(0)
+    run(argv)
 
 if __name__ == '__main__':
     main()
